'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-46cc460d.js');
const utils = require('./utils-4d8ad9ee.js');
const schemaDotOrg = require('./schema-dot-org-dbe0f73a.js');

class BasicEl {
  constructor(value, callback) {
    this.value = "";
    if (typeof value === 'string') {
      this.value = value;
    }
    else if (typeof value === 'number') {
      this.value = value;
    }
    else if (typeof value === 'boolean') {
      this.value = value;
    }
    else {
      console.error('Value type is not supported', value);
    }
    this.callback = callback;
  }
  handleChange(event) {
    if (event.target instanceof HTMLInputElement) {
      if (typeof this.value === 'string') {
        this.value = event.target.value;
      }
      else if (typeof this.value === 'number') {
        this.value = Number(event.target.value);
      }
      else if (typeof this.value === 'boolean') {
        this.value = event.target.checked;
      }
      if (this.callback !== undefined) {
        this.callback(this.value);
      }
    }
  }
  render(editable = true) {
    if (typeof this.value === 'string') {
      return (index.h("input", { type: "text", value: this.value, onInput: (event) => this.handleChange(event), readOnly: !editable, disabled: !editable }));
    }
    else if (typeof this.value === 'number') {
      return (index.h("input", { type: "number", value: this.value, onInput: (event) => this.handleChange(event), readOnly: !editable, disabled: !editable }));
    }
    else if (typeof this.value === 'boolean') {
      return (index.h("input", { type: "checkbox", checked: this.value, onInput: (event) => this.handleChange(event), readOnly: !editable, disabled: !editable }));
    }
    else {
      return (index.h("span", null, "Value type is not supported"));
    }
  }
}
BasicEl.id = '_direct';

class JsonFallbackEl {
  constructor(value, callback) {
    this.value = "";
    this.value = JSON.stringify(value);
    this.callback = callback;
  }
  handleChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.value = JSON.parse(event.target.value);
      if (this.callback !== undefined) {
        this.callback(this.value);
      }
    }
  }
  render() {
    return (index.h("input", { type: "text", value: this.value, onInput: (event) => this.handleChange(event) }));
  }
}
JsonFallbackEl.id = '_fallback';

class ExternalEl {
  //private callback?: (value: any) => void;
  constructor(value) {
    this.value = "";
    if (typeof value['@id'] === 'string') {
      this.value = value['@id'];
    }
    else {
      console.error('Value is not of type string', value);
    }
    //this.callback = callback;
  }
  render() {
    return (index.h("a", { href: this.value, target: '_blank' }, this.value));
  }
}
ExternalEl.id = '@id';

class ValueobjectEl {
  constructor(value, callback) {
    if (value["@value"] !== undefined) {
      let callbackWrapper = (newValue) => {
        value["@value"] = newValue;
        if (callback !== undefined) {
          callback(value);
        }
      };
      this.basicWrapper = new BasicEl(value["@value"], callbackWrapper);
    }
    else {
      console.error('Not a Value Object', value);
    }
  }
  render() {
    if (this.basicWrapper !== undefined) {
      return this.basicWrapper.render();
    }
    else {
      return (index.h("span", null, "Not a Value Object"));
    }
  }
}
ValueobjectEl.id = '@value';

class PropertyValueEl {
  constructor(value, callback) {
    this.name = '';
    let localValue;
    if (value["http://schema.org/value"] !== undefined && value["http://schema.org/value"].length == 1) {
      this.value = value;
      localValue = value["http://schema.org/value"][0]["@value"];
    }
    else {
      console.error("PropertyValue must have a value");
      return;
    }
    if (value["http://schema.org/name"] !== undefined && value["http://schema.org/name"].length == 1) {
      this.name = value["http://schema.org/name"][0]["@value"];
    }
    else {
      console.error("PropertyValue must have a name");
      return;
    }
    let callbackWrapper = (newValue) => {
      value["http://schema.org/value"][0]["@value"] = newValue;
      if (callback !== undefined) {
        callback(value);
      }
    };
    this.basicWrapper = new BasicEl(localValue, callbackWrapper);
  }
  render() {
    if (this.basicWrapper !== undefined) {
      return (index.h("span", { class: "property-container" },
        index.h("span", { class: "property-name" }, this.name + ":"),
        index.h("span", { class: "property-value" }, this.basicWrapper.render())));
    }
    else {
      return (index.h("span", null, "This Property Value is not supported"));
    }
  }
}
PropertyValueEl.id = 'http://schema.org/PropertyValue';

let customElementList = [ExternalEl, ValueobjectEl, PropertyValueEl];
function createCustomElement(id, value, callback) {
  if (id === "_direct") {
    return new BasicEl(value, callback);
  }
  for (let customElement of customElementList) {
    if (customElement.id.toLowerCase() === id.toLowerCase() || customElement.id.toLowerCase() === id.replace('http://', 'https://').toLowerCase()) {
      return new customElement(value, callback);
    }
  }
  return new JsonFallbackEl(value, callback);
}
function getAllCustomElements() {
  return customElementList.map((customElement) => customElement.id);
}

const incldeInputCss = ":host{display:block}.property-container{display:flex;flex-grow:1;justify-content:space-between;align-items:stretch}.property-name{padding-right:1em}.property-value{flex-grow:1}input{width:100%;box-sizing:border-box;}button.edit-button{display:inline-block;vertical-align:middle;background:none;border:none;padding:0px;padding-left:5px;margin:0px;width:15px;height:15px;cursor:pointer}button.edit-button svg{width:15px;height:15px;fill:#777}button.edit-button:hover svg{fill:#000}button.edit-button:active svg{fill:#555}";

const IncldeInput = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.elementSelected = index.createEvent(this, "elementSelected", 7);
    this.isComplex = false;
    this.data = [];
    this.selector = [];
    this.isEditable = true;
    this.value = undefined;
  }
  componentWillLoad() {
    this.initCustomElement();
  }
  watchSelector(_newValue, _oldValue) {
    this.initCustomElement();
  }
  initCustomElement() {
    this.customElement = undefined;
    this.isComplex = false;
    let updateValue = (newValue) => {
      utils.pathTraversalSet(this.data, this.selector, newValue);
    };
    this.value = utils.pathTraversal(this.data, this.selector);
    if (typeof this.value === 'string' || typeof this.value === 'number' || typeof this.value === 'boolean') {
      this.customElement = createCustomElement("_direct", this.value, updateValue);
    }
    else if (this.value['@value'] !== undefined) {
      this.customElement = createCustomElement("@value", this.value, updateValue);
    }
    else if (this.value['@id'] !== undefined) {
      let id_pos = utils.jsonLdGetByID(this.data, this.value['@id']);
      if (id_pos === undefined) {
        this.customElement = createCustomElement("@id", this.value, updateValue);
      }
      else if (utils.pathTraversal(this.data, [id_pos])['@type'] !== undefined) {
        let resolvedObj = utils.pathTraversal(this.data, [id_pos]);
        // Check if type can be represented as a custom element
        for (let type in resolvedObj['@type']) {
          if (getAllCustomElements().includes(resolvedObj['@type'][type])) {
            let updateObjectValue = (newValue) => {
              utils.pathTraversalSet(this.data, [id_pos], newValue);
            };
            this.customElement = createCustomElement(resolvedObj['@type'][type], resolvedObj, updateObjectValue);
            this.isComplex = true;
            this.linkLocation = id_pos;
            break;
          }
        }
        if (this.customElement === undefined) {
          this.linkLocation = id_pos;
        }
      }
    }
    else {
      console.error('Unknown type of input', this.value);
    }
  }
  switchToDetailedView() {
    this.elementSelected.emit({
      selectIndex: this.linkLocation,
    });
  }
  render() {
    var _a;
    let custom_render = (_a = this.customElement) === null || _a === void 0 ? void 0 : _a.render(this.isEditable);
    if (custom_render) {
      return (index.h(index.Host, { class: "property-container" }, custom_render, this.isComplex &&
        index.h("button", { class: "edit-button", onClick: () => this.switchToDetailedView() }, index.h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 512 512" }, index.h("path", { d: "M362.7 19.3L314.3 67.7 444.3 197.7l48.4-48.4c25-25 25-65.5 0-90.5L453.3 19.3c-25-25-65.5-25-90.5 0zm-71 71L58.6 323.5c-10.4 10.4-18 23.3-22.2 37.4L1 481.2C-1.5 489.7 .8 498.8 7 505s15.3 8.5 23.7 6.1l120.3-35.4c14.1-4.2 27-11.8 37.4-22.2L421.7 220.3 291.7 90.3z" })))));
    }
    else if (this.linkLocation !== undefined) {
      return (index.h(index.Host, null, index.h("inclde-view-link", { data: this.data, selector: this.linkLocation })));
    }
    else {
      return (index.h(index.Host, null, index.h("span", null, "Unknown Render Type")));
    }
  }
  static get watchers() { return {
    "selector": ["watchSelector"]
  }; }
};
IncldeInput.style = incldeInputCss;

const incldeViewEditCss = ":host{display:block}label{margin-right:1em;display:flex;align-items:center;justify-items:center}inclde-help-spot{margin-right:0.2em}.flex-container{display:flex;flex-grow:1;justify-content:space-between;align-items:stretch}.flex-value{flex-grow:1}";

const IncldeViewEdit = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.redraw = index.createEvent(this, "redraw", 7);
    this.schemaDotOrgDefinition = schemaDotOrg.SchemaDotOrg.getInstance();
    this.data = undefined;
    this.selectedIndex = undefined;
    this.subElement = undefined;
    this.editMode = false;
    this.attributeName = '';
    this.attributeType = '';
    this.attributeValue = undefined;
  }
  async componentWillLoad() {
    // Load Schema.org definition
    await this.schemaDotOrgDefinition.awaitSchemaDefinition();
    if (this.subElement !== undefined) {
      this.attributeName = this.subElement;
    }
  }
  addAttribute() {
    if (this.attributeName === '' || this.attributeType === '') {
      console.error("Attribute name or type is empty");
      return;
    }
    let newValue;
    let newObj;
    if (this.attributeType === 'string') {
      newValue = this.attributeValue || '';
    }
    else if (this.attributeType === 'number') {
      newValue = this.attributeValue || 0;
    }
    else if (this.attributeType === 'boolean') {
      newValue = this.attributeValue || false;
    }
    else if (this.attributeType === 'array') {
      newValue = [];
    }
    else {
      // Check if selected ID exists
      let pos = utils.jsonLdGetByID(this.data, this.attributeValue);
      if (pos === undefined) {
        newValue = { "@id": this.attributeValue };
        newObj = { "@id": this.attributeValue, "@type": this.attributeType };
      }
      else {
        newValue = { "@id": this.attributeValue };
      }
    }
    if (this.subElement === undefined) {
      if (newObj !== undefined) {
        this.data.push(newObj);
      }
      this.data[this.selectedIndex][this.attributeName] = newValue;
    }
    else if (this.data[this.selectedIndex][this.subElement] !== undefined && Array.isArray(this.data[this.selectedIndex][this.subElement])) {
      if (newObj !== undefined) {
        this.data.push(newObj);
      }
      this.data[this.selectedIndex][this.subElement].push(newValue);
    }
    else {
      console.error("Subelement is not an array");
    }
    this.editMode = false;
    this.attributeValue = undefined;
    this.attributeType = '';
    this.redraw.emit();
  }
  onAttributeNameChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeName = event.target.value;
      this.attributeType = '';
      this.attributeValue = undefined;
    }
  }
  onTypeChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeType = event.target.value;
      this.attributeValue = undefined;
    }
  }
  onValueChange(event) {
    if (event.target instanceof HTMLInputElement) {
      if (this.attributeType === 'string') {
        this.attributeValue = event.target.value;
      }
      else if (this.attributeType === 'number') {
        this.attributeValue = Number(event.target.value);
      }
      else if (this.attributeType === 'boolean') {
        this.attributeValue = event.target.checked;
      }
      else {
        this.attributeValue = event.target.value;
      }
    }
  }
  render() {
    var _a;
    if (this.editMode === false) {
      return (index.h("button", { onClick: () => this.editMode = true }, this.subElement === undefined ? "Add Attribute" : "Add Element"));
    }
    else {
      let propertiesList;
      let type = this.data[this.selectedIndex]["@type"];
      if (Array.isArray(type)) {
        let tempList = [];
        type.forEach((id) => {
          if (typeof id === 'string') {
            tempList = tempList.concat(this.schemaDotOrgDefinition.getPropertiesByType(id) || []);
          }
        });
        tempList = [...new Set(tempList)];
        propertiesList = tempList;
      }
      else if (typeof type === 'string') {
        propertiesList = this.schemaDotOrgDefinition.getPropertiesByType(type);
      }
      propertiesList = propertiesList || [];
      // Remove already existing properties
      propertiesList = propertiesList.filter((property) => {
        return !Object.keys(this.data[this.selectedIndex]).includes(property) &&
          !Object.keys(this.data[this.selectedIndex]).includes(property.replace('https://', 'http://'));
      });
      return (index.h(index.Host, null, index.h("div", null, this.subElement === undefined &&
        index.h("div", { class: "flex-container" }, index.h("label", { htmlFor: "new-attribute", title: 'The relation of the new attribute from the view of the selected object.' }, index.h("inclde-help-spot", { helpText: 'The relation of the new attribute from the view of the selected object.' }), "Relation:"), index.h("input", { id: "new-attribute", type: "text", class: "flex-value", list: "possible_attributes", value: this.attributeName, onInput: (event) => this.onAttributeNameChange(event) }), this.subElement === undefined &&
          index.h("datalist", { id: "possible_attributes" }, propertiesList.map((property) => {
            return (index.h("option", { value: property, label: property.replace("https://schema.org/", "") + " - " + property, key: property }));
          }))), this.attributeName !== "" &&
        index.h("div", { class: "flex-container" }, index.h("label", { htmlFor: "new-type" }, index.h("inclde-help-spot", { helpText: 'Choose which type of information to add as an attribute.' }), "Type:"), index.h("input", { list: "possible_types", id: "new-type", type: "text", class: "flex-value", value: this.attributeType, onInput: (event) => this.onTypeChange(event) }), index.h("datalist", { id: "possible_types" }, index.h("option", { value: "boolean", label: "Native Boolean type" }), index.h("option", { value: "number", label: "Native Number type" }), index.h("option", { value: "string", label: "Native String type" }), index.h("option", { value: "array", label: "Native Array type" }), ((_a = this.schemaDotOrgDefinition.getDataTypesByProperty(this.attributeName)) !== null && _a !== void 0 ? _a : []).map((type) => {
          return (index.h("option", { value: type, label: type.replace("https://schema.org/", "") + " - " + type, key: type }));
        }))), this.attributeType === "boolean" &&
        index.h("div", { class: "flex-container" }, index.h("label", { htmlFor: "new-value" }, index.h("inclde-help-spot", { helpText: 'Choose a boolean value (true or false) for the new attribute.' }), "Value:"), index.h("input", { id: "new-value", type: "checkbox", class: "flex-value", onInput: (event) => this.onValueChange(event) })), this.attributeType === "number" &&
        index.h("div", { class: "flex-container" }, index.h("label", { htmlFor: "new-value" }, index.h("inclde-help-spot", { helpText: 'Choose a number for the new attribute.' }), "Value:"), index.h("input", { id: "new-value", type: "number", class: "flex-value", onInput: (event) => this.onValueChange(event) })), this.attributeType === "string" &&
        index.h("div", { class: "flex-container" }, index.h("label", { htmlFor: "new-value" }, index.h("inclde-help-spot", { helpText: 'Choose a string value for the new attribute.' }), "Value:"), index.h("input", { id: "new-value", type: "text", class: "flex-value", onInput: (event) => this.onValueChange(event) })), this.attributeType === "array" &&
        index.h("div", null), this.attributeType !== "boolean" && this.attributeType !== "number" && this.attributeType !== "string" && this.attributeType !== "array" && this.attributeType !== "" &&
        index.h("div", null, index.h("div", { class: "flex-container" }, index.h("label", { htmlFor: "new-value" }, index.h("inclde-help-spot", { helpText: 'Choose a new ID for a new attribute, or an existing ID to connect an existing one.' }), "ID:"), index.h("input", { list: "possible_ids", id: "new-value", type: "text", class: "flex-value", onInput: (event) => this.onValueChange(event) }), index.h("datalist", { id: "possible_ids" }, utils.jsonLdGetByType(this.data, this.attributeType).map((type) => {
          return (index.h("option", { value: type, key: type }));
        })))), index.h("button", { onClick: () => this.addAttribute() }, "Save"), index.h("button", { onClick: () => this.editMode = false }, "Cancel"))));
    }
  }
  get el() { return index.getElement(this); }
};
IncldeViewEdit.style = incldeViewEditCss;

const incldeViewLinkCss = ":host{display:block}.view-link{cursor:pointer;font-style:italic}.view-link-external{text-decoration:underline;color:blue}";

const IncldeViewLink = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.elementSelected = index.createEvent(this, "elementSelected", 7);
    this.data = [];
    this.selector = undefined;
    this.label = 'Unknown';
  }
  componentWillRender() {
    if (this.selector === undefined) {
      return;
    }
    if (this.data[this.selector]['@id'] !== undefined) {
      this.label = utils.jsonLdNodeToName(this.data[this.selector]);
    }
    else {
      this.label = JSON.stringify(this.data[this.selector]);
    }
  }
  elementClicked() {
    this.elementSelected.emit({
      selectIndex: this.selector,
      selectUrl: this.label,
    });
  }
  render() {
    return (index.h(index.Host, null, index.h("span", { class: this.selector === undefined ? 'view-link view-link-external' : 'view-link', onClick: () => this.elementClicked() }, this.label)));
  }
};
IncldeViewLink.style = incldeViewLinkCss;

exports.inclde_input = IncldeInput;
exports.inclde_view_edit = IncldeViewEdit;
exports.inclde_view_link = IncldeViewLink;

//# sourceMappingURL=inclde-input_3.cjs.entry.js.map