import { Host, h, forceUpdate } from "@stencil/core";
import { flatten, compact } from "jsonld";
import { SchemaDotOrg } from "../../schema-loader/schema-dot-org";
import { ConfigHelper } from "../../utils/config-helper";
export class IncldeEditor {
  constructor() {
    this.configHelper = ConfigHelper.getInstance();
    this.data = undefined;
    this.config = undefined;
    this.dataObject = [];
    this.selectedIndex = undefined;
  }
  async componentWillLoad() {
    // Start loading Schema.org definition
    const schemaDotOrgDefinition = SchemaDotOrg.getInstance();
    schemaDotOrgDefinition.loadSchemaDefinition('https://schema.org/version/latest/schemaorg-current-https.jsonld');
    // Parse jsonld data
    let parsedData;
    if (typeof this.data === 'string') {
      parsedData = JSON.parse(this.data);
    }
    else if (typeof this.data === 'object') {
      parsedData = this.data;
    }
    else {
      throw new Error('Data type not supported');
    }
    this.dataObject = await flatten(parsedData);
    // Load config
    let parsedConfig;
    if (typeof this.config === 'string') {
      parsedConfig = JSON.parse(this.config);
    }
    else if (typeof this.config === 'object') {
      parsedConfig = this.config;
    }
    else {
      throw new Error('Config Data type not supported');
    }
    this.configHelper.loadConfig(parsedConfig);
  }
  selectionHandler(event) {
    if (event.detail.selectIndex === undefined && event.detail.selectUrl !== undefined) {
      window.open(event.detail.selectUrl, '_blank');
    }
    else if (event.detail.selectIndex !== undefined) {
      this.selectedIndex = event.detail.selectIndex;
    }
  }
  redrawHandler() {
    this.dataObject = [...this.dataObject];
    compact(this.dataObject, { "@context": "http://schema.org/" })
      .then(result => this.dataUpdated.emit(result))
      .catch(errorReason => {
      console.warn("Unable to compact JSON. Returning flattened JSON-LD. Reason: ", errorReason);
      this.dataUpdated.emit(this.dataObject);
    });
  }
  closeEditor(data) {
    if (data === undefined) {
      this.editorClosed.emit(data);
      this.render = () => undefined;
      this.selectedIndex = undefined;
      forceUpdate(this);
    }
    else {
      let errorHandler = errorReason => {
        console.warn("Unable to compact JSON. Returning flattened JSON-LD. Reason: ", errorReason);
        this.editorClosed.emit(data);
        //this.render = () => undefined;
        this.selectedIndex = undefined;
        forceUpdate(this);
      };
      compact(data, { "@context": "http://schema.org/" })
        .then(result => {
        this.editorClosed.emit(result);
        //this.render = () => undefined;
        this.selectedIndex = undefined;
        forceUpdate(this);
      }, errorHandler)
        .catch(errorHandler);
    }
  }
  render() {
    return (h(Host, null, h("div", { class: "container" }, h("div", { id: "header" }, h("span", { id: "title" }, this.configHelper.get("title")), h("span", { class: "align-right" }, h("button", { onClick: _e => this.closeEditor(this.dataObject), class: "bg-success" }, "Save"), h("button", { onClick: _e => this.closeEditor(undefined), class: "bg-failure" }, "Cancel"))), h("div", { id: "sidebar" }, h("inclde-sidebar", { data: this.dataObject, selectedIndex: this.selectedIndex })), h("div", { id: "main-view" }, h("inclde-view", { data: this.dataObject, selectedIndex: this.selectedIndex })))));
  }
  static get is() { return "inclde-editor"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["inclde-editor.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["inclde-editor.css"]
    };
  }
  static get properties() {
    return {
      "data": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "object | string",
          "resolved": "object | string",
          "references": {}
        },
        "required": true,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "data",
        "reflect": false
      },
      "config": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "object | string",
          "resolved": "object | string",
          "references": {}
        },
        "required": true,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "config",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "dataObject": {},
      "selectedIndex": {}
    };
  }
  static get events() {
    return [{
        "method": "editorClosed",
        "name": "editorClosed",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Fired when the editor is closed with the save or cancel buttons.\n`event.detail` contains the edited data if the save button was clicked, undefined otherwise."
        },
        "complexType": {
          "original": "NodeObject | NodeObject[] | undefined",
          "resolved": "NodeObject | NodeObject[] | undefined",
          "references": {
            "NodeObject": {
              "location": "import",
              "path": "jsonld",
              "id": ""
            }
          }
        }
      }, {
        "method": "dataUpdated",
        "name": "dataUpdated",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Fired when the data is updated. Can be used to peek into the data from outside the editor.\nNot yet reliably fired.\nReturns the same information as the `editorClosed` event."
        },
        "complexType": {
          "original": "NodeObject | NodeObject[] | string",
          "resolved": "NodeObject | NodeObject[] | string",
          "references": {
            "NodeObject": {
              "location": "import",
              "path": "jsonld",
              "id": ""
            }
          }
        }
      }];
  }
  static get listeners() {
    return [{
        "name": "elementSelected",
        "method": "selectionHandler",
        "target": undefined,
        "capture": false,
        "passive": false
      }, {
        "name": "redraw",
        "method": "redrawHandler",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=inclde-editor.js.map
