import { Host, h } from "@stencil/core";
import { pathTraversal, pathTraversalSet, jsonLdGetByID } from "../../utils/utils";
import { createCustomElement, getAllCustomElements } from "../../custom-elements";
export class IncldeInput {
  constructor() {
    this.isComplex = false;
    this.data = [];
    this.selector = [];
    this.isEditable = true;
    this.value = undefined;
  }
  componentWillLoad() {
    this.initCustomElement();
  }
  watchSelector(_newValue, _oldValue) {
    this.initCustomElement();
  }
  initCustomElement() {
    this.customElement = undefined;
    this.isComplex = false;
    let updateValue = (newValue) => {
      pathTraversalSet(this.data, this.selector, newValue);
    };
    this.value = pathTraversal(this.data, this.selector);
    if (typeof this.value === 'string' || typeof this.value === 'number' || typeof this.value === 'boolean') {
      this.customElement = createCustomElement("_direct", this.value, updateValue);
    }
    else if (this.value['@value'] !== undefined) {
      this.customElement = createCustomElement("@value", this.value, updateValue);
    }
    else if (this.value['@id'] !== undefined) {
      let id_pos = jsonLdGetByID(this.data, this.value['@id']);
      if (id_pos === undefined) {
        this.customElement = createCustomElement("@id", this.value, updateValue);
      }
      else if (pathTraversal(this.data, [id_pos])['@type'] !== undefined) {
        let resolvedObj = pathTraversal(this.data, [id_pos]);
        // Check if type can be represented as a custom element
        for (let type in resolvedObj['@type']) {
          if (getAllCustomElements().includes(resolvedObj['@type'][type])) {
            let updateObjectValue = (newValue) => {
              pathTraversalSet(this.data, [id_pos], newValue);
            };
            this.customElement = createCustomElement(resolvedObj['@type'][type], resolvedObj, updateObjectValue);
            this.isComplex = true;
            this.linkLocation = id_pos;
            break;
          }
        }
        if (this.customElement === undefined) {
          this.linkLocation = id_pos;
        }
      }
    }
    else {
      console.error('Unknown type of input', this.value);
    }
  }
  switchToDetailedView() {
    this.elementSelected.emit({
      selectIndex: this.linkLocation,
    });
  }
  render() {
    var _a;
    let custom_render = (_a = this.customElement) === null || _a === void 0 ? void 0 : _a.render(this.isEditable);
    if (custom_render) {
      return (h(Host, { class: "property-container" }, custom_render, this.isComplex &&
        h("button", { class: "edit-button", onClick: () => this.switchToDetailedView() }, h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 512 512" }, h("path", { d: "M362.7 19.3L314.3 67.7 444.3 197.7l48.4-48.4c25-25 25-65.5 0-90.5L453.3 19.3c-25-25-65.5-25-90.5 0zm-71 71L58.6 323.5c-10.4 10.4-18 23.3-22.2 37.4L1 481.2C-1.5 489.7 .8 498.8 7 505s15.3 8.5 23.7 6.1l120.3-35.4c14.1-4.2 27-11.8 37.4-22.2L421.7 220.3 291.7 90.3z" })))));
    }
    else if (this.linkLocation !== undefined) {
      return (h(Host, null, h("inclde-view-link", { data: this.data, selector: this.linkLocation })));
    }
    else {
      return (h(Host, null, h("span", null, "Unknown Render Type")));
    }
  }
  static get is() { return "inclde-input"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["inclde-input.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["inclde-input.css"]
    };
  }
  static get properties() {
    return {
      "data": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "NodeObject[]",
          "resolved": "NodeObject[]",
          "references": {
            "NodeObject": {
              "location": "import",
              "path": "jsonld",
              "id": ""
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "defaultValue": "[]"
      },
      "selector": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "(string|number)[]",
          "resolved": "(string | number)[]",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "defaultValue": "[]"
      },
      "isEditable": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "is-editable",
        "reflect": false,
        "defaultValue": "true"
      }
    };
  }
  static get states() {
    return {
      "value": {}
    };
  }
  static get events() {
    return [{
        "method": "elementSelected",
        "name": "elementSelected",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "complexType": {
          "original": "SelectEvent",
          "resolved": "{ selectIndex?: number | undefined; selectUrl?: string | undefined; }",
          "references": {
            "SelectEvent": {
              "location": "import",
              "path": "../../utils/events",
              "id": "src/utils/events.ts::SelectEvent"
            }
          }
        }
      }];
  }
  static get watchers() {
    return [{
        "propName": "selector",
        "methodName": "watchSelector"
      }];
  }
}
//# sourceMappingURL=inclde-input.js.map
