import { Host, h } from "@stencil/core";
import { ConfigHelper } from "../../utils/config-helper";
import { pathTraversalSet } from "../../utils/utils";
/**
 * This component represents the properties of a selected entity.
 */
export class IncldeView {
  constructor() {
    this.config = ConfigHelper.getInstance();
    this.data = undefined;
    this.selectedIndex = undefined;
  }
  deleteElement(selector) {
    pathTraversalSet(this.data, selector, undefined);
    this.redraw.emit();
  }
  renderHTML() {
    if (this.selectedIndex === undefined) {
      return;
    }
    else {
      let id = this.data[this.selectedIndex]["@id"] || "";
      let type = this.data[this.selectedIndex]["@type"] || [];
      return (h("div", null, Object.entries(this.data[this.selectedIndex]).map(([key, value]) => {
        const keySettings = this.config.getSettingsForObj(id, type, key);
        if (Array.isArray(value) && keySettings["visible"] === true) {
          return (h("div", { key: key }, h("span", { class: "array-name" }, key.replace("http://schema.org/", ""), ":"), this.renderPredicateActionButtons(key), h("div", { class: "array-entry" }, value.map((_x, index) => (h("div", { class: "array-element property-container" }, h("inclde-input", { class: "property-value", data: this.data, selector: [this.selectedIndex, key, index], isEditable: keySettings["editable"] }), this.renderPropertyActionButtons(index, key)))), h("inclde-view-edit", { data: this.data, selectedIndex: this.selectedIndex, subElement: key }))));
        }
        else if (keySettings["visible"] === true) {
          return (h("div", { class: "property-container", key: key }, h("span", { class: "property-name" }, key + ":"), h("inclde-input", { class: "property-value", data: this.data, selector: [this.selectedIndex, key], isEditable: keySettings["editable"] }), keySettings["editable"] && this.renderPredicateActionButtons(key)));
        }
      }), this.config.get("allowNewAttributes") && this.renderAddAttributeButton(this.selectedIndex)));
    }
  }
  /**
   * Renders html to enable the user to add further attributes to the selected object.
   *
   * @param selectedIndex the index of the selected object of this view.
   * @returns the html
   */
  renderAddAttributeButton(selectedIndex) {
    return h("div", { class: "editing-container" }, h("inclde-view-edit", { data: this.data, selectedIndex: selectedIndex }));
  }
  /**
   * Returns a delete button for elements which do not have any other possible action.
   *
   * @param key the key to delete
   * @returns the html
   */
  renderPredicateActionButtons(key) {
    return h("div", { class: "interface-buttons offset" }, h("button", { class: "danger-btn", onClick: () => this.deleteElement([this.selectedIndex, key]) }, this.renderDeleteIcon()));
  }
  /**
   * Adds buttons for moving up and down or deleting an object.
   *
   * @param index current index of the object
   * @param key the key/name of the object
   * @param value the object
   * @returns the html to render
   */
  renderPropertyActionButtons(index, key) {
    return h("div", { class: "interface-buttons" }, h("button", { class: "danger-btn", onClick: () => this.deleteElement([this.selectedIndex, key, index]) }, this.renderDeleteIcon()));
  }
  renderDeleteIcon() {
    return h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 384 512" }, h("path", { d: "M342.6 150.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L192 210.7 86.6 105.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L146.7 256 41.4 361.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L192 301.3 297.4 406.6c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L237.3 256 342.6 150.6z" }));
  }
  render() {
    return (h(Host, null, this.renderHTML()));
  }
  static get is() { return "inclde-view"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["inclde-view.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["inclde-view.css"]
    };
  }
  static get properties() {
    return {
      "data": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "NodeObject[]",
          "resolved": "NodeObject[]",
          "references": {
            "NodeObject": {
              "location": "import",
              "path": "jsonld",
              "id": ""
            }
          }
        },
        "required": true,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        }
      },
      "selectedIndex": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number | undefined",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": "The index of the object to render."
        },
        "attribute": "selected-index",
        "reflect": false
      }
    };
  }
  static get events() {
    return [{
        "method": "redraw",
        "name": "redraw",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "complexType": {
          "original": "CustomEvent",
          "resolved": "CustomEvent<any>",
          "references": {
            "CustomEvent": {
              "location": "global",
              "id": "global::CustomEvent"
            }
          }
        }
      }];
  }
}
//# sourceMappingURL=inclde-view.js.map
