import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { S as SchemaDotOrg } from './schema-dot-org.js';
import { i as isNullish, j as jsonLdGetByType, a as jsonLdGetByID, b as jsonLdNodeToTypeIds } from './utils.js';
import { d as defineCustomElement$1 } from './inclde-help-spot2.js';

const incldeAddNodeDialogueCss = ":host{display:block}.container{margin:1em;padding-top:1em;border-top:1px solid #aaa}.flex-container{display:flex}.flex-value{flex-grow:1}button{display:flex}inclde-help-spot{margin-right:0.3em}.flex-container+.flex-container{margin-top:0.2em}button+button{margin-left:0.5em}label+input{margin-left:0.5em}";

const IncldeAddNodeDialogue = /*@__PURE__*/ proxyCustomElement(class IncldeAddNodeDialogue extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.nodeAdded = createEvent(this, "nodeAdded", 7);
    this.schemaDotOrgDefinition = SchemaDotOrg.getInstance();
    this.typeSpecificContent = [
      {
        "name": "boolean",
        "helpText": "Choose a boolean value (true or false) for the new attribute.",
        "inputElementType": "checkbox",
      },
      {
        "name": "number",
        "helpText": "Choose a number for the new attribute.",
        "inputElementType": "number",
      },
      {
        "name": "string",
        "helpText": "Choose a string value for the new attribute.",
        "inputElementType": "text",
      },
      {
        "name": "array"
      },
    ];
    this.data = undefined;
    this.relationTo = undefined;
    this.allowPrimitives = false;
    this.isOpen = false;
    this.attributeRelation = '';
    this.attributeType = '';
    this.attributeValue = undefined;
  }
  componentWillLoad() {
    this.schemaDotOrgDefinition.awaitSchemaDefinition();
  }
  /**
   * Sets a relation to the given ID for the relationTo node.
   * @param id The ID of the node to point at.
   */
  setRelation(id) {
    if (isNullish(id) || isNullish(this.relationTo)) {
      return;
    }
    let relatedToIndex = jsonLdGetByID(this.data, this.relationTo);
    if (relatedToIndex === undefined) {
      return [];
    }
    let relatedToNode = this.data[relatedToIndex];
    console.log("found relatedToNode", relatedToNode);
    if (relatedToNode[this.attributeRelation] === undefined) {
      relatedToNode[this.attributeRelation] = id;
    }
    else if (Array.isArray(relatedToNode[this.attributeRelation])) {
      let array = relatedToNode[this.attributeRelation];
      array.push(id);
      relatedToNode[this.attributeRelation] = array;
    }
    else {
      relatedToNode[this.attributeRelation] = [relatedToNode[this.attributeRelation], id];
    }
  }
  addAttribute() {
    var _a, _b, _c;
    if (this.attributeType === '') {
      console.error("Attribute name or type is empty");
      return;
    }
    let newValue;
    let newObj;
    if (this.attributeType === 'string') {
      newValue = (_a = this.attributeValue) !== null && _a !== void 0 ? _a : '';
    }
    else if (this.attributeType === 'number') {
      newValue = (_b = this.attributeValue) !== null && _b !== void 0 ? _b : 0;
    }
    else if (this.attributeType === 'boolean') {
      newValue = (_c = this.attributeValue) !== null && _c !== void 0 ? _c : false;
    }
    else if (this.attributeType === 'array') {
      newValue = [];
    }
    else {
      // Check if selected ID exists
      let pos = jsonLdGetByID(this.data, this.attributeValue);
      if (pos === undefined) {
        newValue = { "@id": this.attributeValue };
        newObj = { "@id": this.attributeValue, "@type": this.attributeType };
      }
      else {
        newValue = { "@id": this.attributeValue };
      }
    }
    if (newObj !== undefined) {
      this.data.push(newObj);
    }
    this.setRelation(newValue);
    this.isOpen = false;
    this.attributeValue = undefined;
    this.attributeType = '';
    this.nodeAdded.emit();
  }
  render() {
    return (h(Host, null, this.isOpen ? this.renderOpenState() : this.renderClosedState()));
  }
  renderClosedState() {
    return (h("div", { class: "container" }, h("button", { onClick: () => this.isOpen = true }, h("inclde-help-spot", { helpText: 'Creates a new item. It can be connected with others later.' }), h("span", null, "Create new item"))));
  }
  renderOpenState() {
    // Render three input fields for name, type and value, and a button to add the attribute.
    // But only show the next field each if the previous field is filled out.
    let relationRequired = !isNullish(this.relationTo);
    let hasValueInput = this.attributeValue !== undefined && (typeof this.attributeValue !== 'string' || this.attributeValue.length > 0);
    return (h("div", { class: "container" }, relationRequired && this.renderRelationField(), (this.attributeRelation.length > 0 || !relationRequired) && this.renderTypeField(), (this.attributeType.length > 0) && this.renderValueField(), h("div", { class: "flex-container" }, h("button", { onClick: () => this.addAttribute(), disabled: !(this.attributeType.length > 0 && hasValueInput) }, "Create"), h("button", { onClick: () => this.isOpen = false }, "Cancel"))));
  }
  renderValueField() {
    let isPrimitiveType = this.typeSpecificContent.map((content) => content.name).includes(this.attributeType);
    let renderIdInput = h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value", class: "flex-container" }, h("inclde-help-spot", { helpText: 'Choose a new ID for a new attribute, or an existing ID to connect an existing one.' }), "ID:"), h("input", { list: "possible_ids", id: "new-value", type: "text", class: "flex-value", onInput: (event) => this.onValueChange(event), required: true }), h("datalist", { id: "possible_ids" }, jsonLdGetByType(this.data, this.attributeType).map((type) => {
      return (h("option", { value: type, key: type }));
    })));
    if (isPrimitiveType) {
      return this.renderPrimitiveInput();
    }
    else {
      return renderIdInput;
    }
  }
  renderPrimitiveInput() {
    var _a, _b, _c;
    let isPrimitiveType = this.typeSpecificContent.map((content) => content.name).includes(this.attributeType);
    let hasInputElementType = ((_a = this.typeSpecificContent.find((content) => content.name === this.attributeType)) === null || _a === void 0 ? void 0 : _a.inputElementType) !== undefined;
    if (!isPrimitiveType || !hasInputElementType) {
      return;
    }
    return h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value", class: "flex-container" }, h("inclde-help-spot", { helpText: (_b = this.typeSpecificContent.find((content) => content.name === this.attributeType)) === null || _b === void 0 ? void 0 : _b.helpText }), "Value:"), h("input", { id: "new-value", type: (_c = this.typeSpecificContent.find((content) => content.name === this.attributeType)) === null || _c === void 0 ? void 0 : _c.inputElementType, class: "flex-value", onInput: (event) => this.onValueChange(event), required: true }));
  }
  renderRelationField() {
    return (h("div", { class: "flex-container" }, h("label", { htmlFor: "new-relation", title: 'The relation of the new attribute from the view of the selected object.', class: "flex-container" }, h("inclde-help-spot", { helpText: 'The relation of the new attribute from the view of the selected object.' }), "Relation:"), h("input", { id: "new-relation", type: "text", class: "flex-value", list: "possible_attributes", value: this.attributeRelation, onInput: (event) => this.onAttributeNameChange(event) }), h("datalist", { id: "possible_attributes" }, this.getRelationList().map((property) => {
      return (h("option", { value: property, label: property.replace("https://schema.org/", "") + " - " + property, key: property }));
    }))));
  }
  renderTypeField() {
    var _a;
    let relationIsNullish = this.attributeRelation === null || this.attributeRelation === undefined || this.attributeRelation === '';
    return (h("div", { class: "flex-container" }, h("label", { htmlFor: "new-type", class: "flex-container" }, h("inclde-help-spot", { helpText: 'Choose which type of information to add as an attribute.' }), "Type:"), h("input", { list: "possible_types", id: "new-type", type: "text", class: "flex-value", value: this.attributeType, onInput: (event) => this.onTypeChange(event), required: true }), h("datalist", { id: "possible_types" }, this.allowPrimitives && h("option", { value: "boolean", label: "Native Boolean type" }), this.allowPrimitives && h("option", { value: "number", label: "Native Number type" }), this.allowPrimitives && h("option", { value: "string", label: "Native String type" }), this.allowPrimitives && h("option", { value: "array", label: "Native Array type" }), !relationIsNullish && ((_a = this.schemaDotOrgDefinition.getDataTypesByProperty(this.attributeRelation)) !== null && _a !== void 0 ? _a : []).map((type) => {
      return (h("option", { value: type, label: type.replace("https://schema.org/", "") + " - " + type, key: type }));
    }), relationIsNullish && (this.schemaDotOrgDefinition.getAllClasses()).map((type) => {
      return (h("option", { value: type, label: type.replace("https://schema.org/", "") + " - " + type, key: type }));
    }))));
  }
  onValueChange(event) {
    if (event.target instanceof HTMLInputElement) {
      if (this.attributeType === 'string') {
        this.attributeValue = event.target.value;
      }
      else if (this.attributeType === 'number') {
        this.attributeValue = Number(event.target.value);
      }
      else if (this.attributeType === 'boolean') {
        this.attributeValue = event.target.checked;
      }
      else {
        this.attributeValue = event.target.value;
      }
    }
  }
  onTypeChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeType = event.target.value;
      this.attributeValue = undefined;
    }
  }
  onAttributeNameChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeRelation = event.target.value;
      this.attributeType = '';
      this.attributeValue = undefined;
    }
  }
  getRelationList() {
    if (isNullish(this.relationTo)) {
      return [];
    }
    else {
      let propertiesList;
      let relatedToIndex = jsonLdGetByID(this.data, this.relationTo);
      if (relatedToIndex === undefined) {
        return [];
      }
      let relatedToNode = this.data[relatedToIndex];
      let typeIDs = jsonLdNodeToTypeIds(relatedToNode);
      //let typeNames: string[] = typeIDs
      //  .map((id) => jsonLdGetByID(this.data, id))
      //  .filter((index) => index !== undefined)
      //  .map((index) => this.data[index!])
      //  .filter((node) => node !== undefined)
      //  .map((node) => jsonLdNodeToName(node));
      let type = typeIDs;
      if (Array.isArray(type)) {
        let tempList = [];
        type.forEach((id) => {
          var _a;
          if (typeof id === 'string') {
            tempList = tempList.concat((_a = this.schemaDotOrgDefinition.getPropertiesByType(id)) !== null && _a !== void 0 ? _a : []);
          }
        });
        tempList = [...new Set(tempList)];
        propertiesList = tempList;
      }
      else if (typeof type === 'string') {
        propertiesList = this.schemaDotOrgDefinition.getPropertiesByType(type);
      }
      propertiesList = propertiesList !== null && propertiesList !== void 0 ? propertiesList : [];
      // Remove already existing properties
      propertiesList = propertiesList.filter((property) => {
        return !Object.keys(this.relationTo).includes(property) &&
          !Object.keys(this.relationTo).includes(property.replace('https://', 'http://'));
      });
      return propertiesList;
    }
  }
  static get style() { return incldeAddNodeDialogueCss; }
}, [1, "inclde-add-node-dialogue", {
    "data": [16],
    "relationTo": [1, "relation-to"],
    "allowPrimitives": [4, "allow-primitives"],
    "isOpen": [32],
    "attributeRelation": [32],
    "attributeType": [32],
    "attributeValue": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["inclde-add-node-dialogue", "inclde-help-spot"];
  components.forEach(tagName => { switch (tagName) {
    case "inclde-add-node-dialogue":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, IncldeAddNodeDialogue);
      }
      break;
    case "inclde-help-spot":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { IncldeAddNodeDialogue as I, defineCustomElement as d };

//# sourceMappingURL=inclde-add-node-dialogue2.js.map