import { proxyCustomElement, HTMLElement, createEvent, forceUpdate, h, Host } from '@stencil/core/internal/client';
import { S as SchemaDotOrg, j as jsonld } from './schema-dot-org.js';
import { C as ConfigHelper, d as defineCustomElement$4 } from './inclde-view2.js';
import { d as defineCustomElement$9 } from './inclde-add-node-dialogue2.js';
import { d as defineCustomElement$8 } from './inclde-help-spot2.js';
import { d as defineCustomElement$7 } from './inclde-input2.js';
import { d as defineCustomElement$6 } from './inclde-sidebar2.js';
import { d as defineCustomElement$5 } from './inclde-sidebar-element2.js';
import { d as defineCustomElement$3 } from './inclde-view-edit2.js';
import { d as defineCustomElement$2 } from './inclde-view-link2.js';

const incldeEditorCss = ":host{--font-family:Sans-Serif;--color-text:#000000;--color-bg-default:#ffffff;--color-bg-secondary:#f5f5f5;}:root{font-family:var(--font-family);display:block;padding:0px;margin:0px;height:100%;width:100%}#main-view{flex:1;flex-shrink:1;min-width:25em}#sidebar{flex:1;flex-shrink:10;background-color:#f5f5f5;border-right:1px solid #e5e5e5;max-width:max-content;height:100%;padding-left:5px}.container{display:flex;flex-wrap:wrap;column-gap:1em}#header{background-color:var(--color-bg-secondary);padding:0px;margin:0px;width:100%;border-bottom:#e5e5e5 1px solid}#title{font-weight:bold;font-size:1.5rem;vertical-align:middle;padding-left:0.5rem;line-height:2.5rem}.align-right{float:right}button{background-color:#f5f5f5;border:1px solid #e5e5e5;border-radius:0.25rem;padding:0.375rem 0.75rem;margin:0.25rem;cursor:pointer}button.bg-success{background-color:#d4edda;border-color:#c3e6cb;color:#155724}button.bg-failure{background-color:#f8d7da;border-color:#f5c6cb;color:#721c24}button:hover{background-color:#e5e5e5}button.bg-success:hover{background-color:#c3e6cb}button.bg-failure:hover{background-color:#f1b0b7}button:active{background-color:#d5d5d5}button.bg-success:active{background-color:#b1dfbb}button.bg-failure:active{background-color:#e4a7ad}";

const IncldeEditor$1 = /*@__PURE__*/ proxyCustomElement(class IncldeEditor extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.editorClosed = createEvent(this, "editorClosed", 7);
    this.dataUpdated = createEvent(this, "dataUpdated", 7);
    this.configHelper = ConfigHelper.getInstance();
    this.data = undefined;
    this.config = undefined;
    this.dataObject = [];
    this.selectedIndex = undefined;
  }
  async componentWillLoad() {
    // Start loading Schema.org definition
    const schemaDotOrgDefinition = SchemaDotOrg.getInstance();
    schemaDotOrgDefinition.loadSchemaDefinition('https://schema.org/version/latest/schemaorg-current-https.jsonld');
    // Parse jsonld data
    let parsedData;
    if (typeof this.data === 'string') {
      parsedData = JSON.parse(this.data);
    }
    else if (typeof this.data === 'object') {
      parsedData = this.data;
    }
    else {
      throw new Error('Data type not supported');
    }
    this.dataObject = await jsonld.flatten(parsedData);
    // Load config
    let parsedConfig;
    if (typeof this.config === 'string') {
      parsedConfig = JSON.parse(this.config);
    }
    else if (typeof this.config === 'object') {
      parsedConfig = this.config;
    }
    else {
      throw new Error('Config Data type not supported');
    }
    this.configHelper.loadConfig(parsedConfig);
  }
  selectionHandler(event) {
    if (event.detail.selectIndex === undefined && event.detail.selectUrl !== undefined) {
      window.open(event.detail.selectUrl, '_blank');
    }
    else if (event.detail.selectIndex !== undefined) {
      this.selectedIndex = event.detail.selectIndex;
    }
  }
  redrawHandler() {
    this.dataObject = [...this.dataObject];
    jsonld.compact(this.dataObject, { "@context": "http://schema.org/" })
      .then(result => this.dataUpdated.emit(result))
      .catch(errorReason => {
      console.warn("Unable to compact JSON. Returning flattened JSON-LD. Reason: ", errorReason);
      this.dataUpdated.emit(this.dataObject);
    });
  }
  closeEditor(data) {
    if (data === undefined) {
      this.editorClosed.emit(data);
      this.render = () => undefined;
      this.selectedIndex = undefined;
      forceUpdate(this);
    }
    else {
      let errorHandler = errorReason => {
        console.warn("Unable to compact JSON. Returning flattened JSON-LD. Reason: ", errorReason);
        this.editorClosed.emit(data);
        //this.render = () => undefined;
        this.selectedIndex = undefined;
        forceUpdate(this);
      };
      jsonld.compact(data, { "@context": "http://schema.org/" })
        .then(result => {
        this.editorClosed.emit(result);
        //this.render = () => undefined;
        this.selectedIndex = undefined;
        forceUpdate(this);
      }, errorHandler)
        .catch(errorHandler);
    }
  }
  render() {
    return (h(Host, null, h("div", { class: "container" }, h("div", { id: "header" }, h("span", { id: "title" }, this.configHelper.get("title")), h("span", { class: "align-right" }, h("button", { onClick: _e => this.closeEditor(this.dataObject), class: "bg-success" }, "Save"), h("button", { onClick: _e => this.closeEditor(undefined), class: "bg-failure" }, "Cancel"))), h("div", { id: "sidebar" }, h("inclde-sidebar", { data: this.dataObject, selectedIndex: this.selectedIndex })), h("div", { id: "main-view" }, h("inclde-view", { data: this.dataObject, selectedIndex: this.selectedIndex })))));
  }
  static get style() { return incldeEditorCss; }
}, [1, "inclde-editor", {
    "data": [1],
    "config": [1],
    "dataObject": [32],
    "selectedIndex": [32]
  }, [[0, "elementSelected", "selectionHandler"], [0, "redraw", "redrawHandler"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["inclde-editor", "inclde-add-node-dialogue", "inclde-help-spot", "inclde-input", "inclde-sidebar", "inclde-sidebar-element", "inclde-view", "inclde-view-edit", "inclde-view-link"];
  components.forEach(tagName => { switch (tagName) {
    case "inclde-editor":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, IncldeEditor$1);
      }
      break;
    case "inclde-add-node-dialogue":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "inclde-help-spot":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "inclde-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "inclde-sidebar":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "inclde-sidebar-element":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "inclde-view":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "inclde-view-edit":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "inclde-view-link":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const IncldeEditor = IncldeEditor$1;
const defineCustomElement = defineCustomElement$1;

export { IncldeEditor, defineCustomElement };

//# sourceMappingURL=inclde-editor.js.map