import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as jsonLdGetSubNodes, e as jsonLdNodeToName, f as jsonLdNodeToType, a as jsonLdGetByID } from './utils.js';

const incldeSidebarElementCss = ":host{display:block;padding:0px}.hidden{display:none}.sidebar-label{font-size:1em;margin:2px;padding:2px}.sidebar-type{font-size:0.75em;line-height:1em;color:#212121;border:1px solid #898989;border-radius:5px;margin:2px;padding:2px;display:inline-block}.sidebar-item{padding-right:1em}.sidebar-item-child{padding-left:20px}.selected{background-color:#ccc !important}.sidebar-item-header{cursor:pointer;padding-bottom:2px;padding-top:2px;display:flex}.button-column{flex:0}.span-column{display:flex;flex:1;flex-direction:column}.sidebar-item-header:hover{background-color:#dbdbdb}.sidebar-propertyname{font-size:0.9em;font-style:italic}.sidebar-properties{padding-left:10px}.sidebar-expand-button{vertical-align:bottom;background:none;border:none;padding:0px;margin:0px;width:25px;height:25px;cursor:pointer}.sidebar-expand-button svg{width:20px;height:20px;fill:#777}.sidebar-expand-button:hover svg{fill:#000}.sidebar-expand-button:active svg{fill:#555}";

const IncldeSidebarElement = /*@__PURE__*/ proxyCustomElement(class IncldeSidebarElement extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.elementSelected = createEvent(this, "elementSelected", 7);
    this.data = undefined;
    this.selector = undefined;
    this.globalSelector = undefined;
    this.expanded = false;
    this.selected = false;
    this.selctedElement = {};
  }
  updateSelectedElement() {
    if (this.selector == undefined) {
      this.selctedElement = {};
      this.selected = false;
      return;
    }
    this.selctedElement = this.data[this.selector];
    this.selected = this.selector == this.globalSelector;
  }
  componentWillLoad() {
    this.updateSelectedElement();
  }
  toggleExpanded(e) {
    this.expanded = !this.expanded;
    e.stopPropagation();
  }
  elementClicked() {
    this.elementSelected.emit({
      selectIndex: this.selector,
    });
  }
  render() {
    const subNodes = jsonLdGetSubNodes(this.data, this.selctedElement);
    return (h(Host, null, h("div", { class: 'sidebar-item' }, h("div", { onClick: () => this.elementClicked(), class: this.selected ? 'sidebar-item-header selected' : 'sidebar-item-header' }, subNodes.size > 0 && h("div", { class: "column button-column" }, h("button", { type: "button", class: "sidebar-expand-button", onClick: (e) => this.toggleExpanded(e) }, this.expanded ? this.renderChildrenIndicatorOpen() : this.renderChildrenIndicatorClosed())), h("div", { class: "column header-column" }, h("span", { class: "sidebar-label" }, jsonLdNodeToName(this.selctedElement)), jsonLdNodeToType(this.selctedElement).map((y) => h("span", { class: "sidebar-type", key: y }, y)))), subNodes.size > 0 && h("div", { class: "sidebar-item-children" }, h("div", { class: this.expanded ? 'sidebar-item-child' : 'sidebar-item-child hidden' }, this.expanded && Array.from(subNodes).map(([path, id]) => {
      return (h("div", null, h("span", { class: "sidebar-propertyname" }, path.split("/").pop(), ":"), h("div", { class: "sidebar-properties" }, id.map((id) => h("inclde-sidebar-element", { data: this.data, selector: jsonLdGetByID(this.data, id), globalSelector: this.globalSelector })))));
    }))))));
  }
  renderChildrenIndicatorOpen() {
    // Font Awesome SVG icon from https://fontawesome.com/icons/caret-down?f=classic&s=solid
    return h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "1em", viewBox: "0 0 320 512" }, "<!--! Font Awesome Free 6.4.2 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. -->", h("path", { d: "M137.4 374.6c12.5 12.5 32.8 12.5 45.3 0l128-128c9.2-9.2 11.9-22.9 6.9-34.9s-16.6-19.8-29.6-19.8L32 192c-12.9 0-24.6 7.8-29.6 19.8s-2.2 25.7 6.9 34.9l128 128z" }));
  }
  renderChildrenIndicatorClosed() {
    // Font Awesome SVG icon from https://fontawesome.com/icons/caret-right?f=classic&s=solid
    return h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "1em", viewBox: "0 0 256 512" }, "<!--! Font Awesome Free 6.4.2 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. -->", h("path", { d: "M246.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-128-128c-9.2-9.2-22.9-11.9-34.9-6.9s-19.8 16.6-19.8 29.6l0 256c0 12.9 7.8 24.6 19.8 29.6s25.7 2.2 34.9-6.9l128-128z" }));
  }
  static get watchers() { return {
    "selector": ["updateSelectedElement"],
    "data": ["updateSelectedElement"],
    "globalSelector": ["updateSelectedElement"]
  }; }
  static get style() { return incldeSidebarElementCss; }
}, [1, "inclde-sidebar-element", {
    "data": [16],
    "selector": [2],
    "globalSelector": [2, "global-selector"],
    "expanded": [32],
    "selected": [32],
    "selctedElement": [32]
  }, undefined, {
    "selector": ["updateSelectedElement"],
    "data": ["updateSelectedElement"],
    "globalSelector": ["updateSelectedElement"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["inclde-sidebar-element", "inclde-sidebar-element"];
  components.forEach(tagName => { switch (tagName) {
    case "inclde-sidebar-element":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, IncldeSidebarElement);
      }
      break;
    case "inclde-sidebar-element":
      if (!customElements.get(tagName)) {
        defineCustomElement();
      }
      break;
  } });
}

export { IncldeSidebarElement as I, defineCustomElement as d };

//# sourceMappingURL=inclde-sidebar-element2.js.map