import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { S as SchemaDotOrg } from './schema-dot-org.js';
import { j as jsonLdGetByType, a as jsonLdGetByID } from './utils.js';
import { d as defineCustomElement$1 } from './inclde-help-spot2.js';

const incldeViewEditCss = ":host{display:block}label{margin-right:1em;display:flex;align-items:center;justify-items:center}inclde-help-spot{margin-right:0.2em}.flex-container{display:flex;flex-grow:1;justify-content:space-between;align-items:stretch}.flex-value{flex-grow:1}";

const IncldeViewEdit = /*@__PURE__*/ proxyCustomElement(class IncldeViewEdit extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.redraw = createEvent(this, "redraw", 7);
    this.schemaDotOrgDefinition = SchemaDotOrg.getInstance();
    this.data = undefined;
    this.selectedIndex = undefined;
    this.subElement = undefined;
    this.editMode = false;
    this.attributeName = '';
    this.attributeType = '';
    this.attributeValue = undefined;
  }
  async componentWillLoad() {
    // Load Schema.org definition
    await this.schemaDotOrgDefinition.awaitSchemaDefinition();
    if (this.subElement !== undefined) {
      this.attributeName = this.subElement;
    }
  }
  addAttribute() {
    if (this.attributeName === '' || this.attributeType === '') {
      console.error("Attribute name or type is empty");
      return;
    }
    let newValue;
    let newObj;
    if (this.attributeType === 'string') {
      newValue = this.attributeValue || '';
    }
    else if (this.attributeType === 'number') {
      newValue = this.attributeValue || 0;
    }
    else if (this.attributeType === 'boolean') {
      newValue = this.attributeValue || false;
    }
    else if (this.attributeType === 'array') {
      newValue = [];
    }
    else {
      // Check if selected ID exists
      let pos = jsonLdGetByID(this.data, this.attributeValue);
      if (pos === undefined) {
        newValue = { "@id": this.attributeValue };
        newObj = { "@id": this.attributeValue, "@type": this.attributeType };
      }
      else {
        newValue = { "@id": this.attributeValue };
      }
    }
    if (this.subElement === undefined) {
      if (newObj !== undefined) {
        this.data.push(newObj);
      }
      this.data[this.selectedIndex][this.attributeName] = newValue;
    }
    else if (this.data[this.selectedIndex][this.subElement] !== undefined && Array.isArray(this.data[this.selectedIndex][this.subElement])) {
      if (newObj !== undefined) {
        this.data.push(newObj);
      }
      this.data[this.selectedIndex][this.subElement].push(newValue);
    }
    else {
      console.error("Subelement is not an array");
    }
    this.editMode = false;
    this.attributeValue = undefined;
    this.attributeType = '';
    this.redraw.emit();
  }
  onAttributeNameChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeName = event.target.value;
      this.attributeType = '';
      this.attributeValue = undefined;
    }
  }
  onTypeChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeType = event.target.value;
      this.attributeValue = undefined;
    }
  }
  onValueChange(event) {
    if (event.target instanceof HTMLInputElement) {
      if (this.attributeType === 'string') {
        this.attributeValue = event.target.value;
      }
      else if (this.attributeType === 'number') {
        this.attributeValue = Number(event.target.value);
      }
      else if (this.attributeType === 'boolean') {
        this.attributeValue = event.target.checked;
      }
      else {
        this.attributeValue = event.target.value;
      }
    }
  }
  render() {
    var _a;
    if (this.editMode === false) {
      return (h("button", { onClick: () => this.editMode = true }, this.subElement === undefined ? "Add Attribute" : "Add Element"));
    }
    else {
      let propertiesList;
      let type = this.data[this.selectedIndex]["@type"];
      if (Array.isArray(type)) {
        let tempList = [];
        type.forEach((id) => {
          if (typeof id === 'string') {
            tempList = tempList.concat(this.schemaDotOrgDefinition.getPropertiesByType(id) || []);
          }
        });
        tempList = [...new Set(tempList)];
        propertiesList = tempList;
      }
      else if (typeof type === 'string') {
        propertiesList = this.schemaDotOrgDefinition.getPropertiesByType(type);
      }
      propertiesList = propertiesList || [];
      // Remove already existing properties
      propertiesList = propertiesList.filter((property) => {
        return !Object.keys(this.data[this.selectedIndex]).includes(property) &&
          !Object.keys(this.data[this.selectedIndex]).includes(property.replace('https://', 'http://'));
      });
      return (h(Host, null, h("div", null, this.subElement === undefined &&
        h("div", { class: "flex-container" }, h("label", { htmlFor: "new-attribute", title: 'The relation of the new attribute from the view of the selected object.' }, h("inclde-help-spot", { helpText: 'The relation of the new attribute from the view of the selected object.' }), "Relation:"), h("input", { id: "new-attribute", type: "text", class: "flex-value", list: "possible_attributes", value: this.attributeName, onInput: (event) => this.onAttributeNameChange(event) }), this.subElement === undefined &&
          h("datalist", { id: "possible_attributes" }, propertiesList.map((property) => {
            return (h("option", { value: property, label: property.replace("https://schema.org/", "") + " - " + property, key: property }));
          }))), this.attributeName !== "" &&
        h("div", { class: "flex-container" }, h("label", { htmlFor: "new-type" }, h("inclde-help-spot", { helpText: 'Choose which type of information to add as an attribute.' }), "Type:"), h("input", { list: "possible_types", id: "new-type", type: "text", class: "flex-value", value: this.attributeType, onInput: (event) => this.onTypeChange(event) }), h("datalist", { id: "possible_types" }, h("option", { value: "boolean", label: "Native Boolean type" }), h("option", { value: "number", label: "Native Number type" }), h("option", { value: "string", label: "Native String type" }), h("option", { value: "array", label: "Native Array type" }), ((_a = this.schemaDotOrgDefinition.getDataTypesByProperty(this.attributeName)) !== null && _a !== void 0 ? _a : []).map((type) => {
          return (h("option", { value: type, label: type.replace("https://schema.org/", "") + " - " + type, key: type }));
        }))), this.attributeType === "boolean" &&
        h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value" }, h("inclde-help-spot", { helpText: 'Choose a boolean value (true or false) for the new attribute.' }), "Value:"), h("input", { id: "new-value", type: "checkbox", class: "flex-value", onInput: (event) => this.onValueChange(event) })), this.attributeType === "number" &&
        h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value" }, h("inclde-help-spot", { helpText: 'Choose a number for the new attribute.' }), "Value:"), h("input", { id: "new-value", type: "number", class: "flex-value", onInput: (event) => this.onValueChange(event) })), this.attributeType === "string" &&
        h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value" }, h("inclde-help-spot", { helpText: 'Choose a string value for the new attribute.' }), "Value:"), h("input", { id: "new-value", type: "text", class: "flex-value", onInput: (event) => this.onValueChange(event) })), this.attributeType === "array" &&
        h("div", null), this.attributeType !== "boolean" && this.attributeType !== "number" && this.attributeType !== "string" && this.attributeType !== "array" && this.attributeType !== "" &&
        h("div", null, h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value" }, h("inclde-help-spot", { helpText: 'Choose a new ID for a new attribute, or an existing ID to connect an existing one.' }), "ID:"), h("input", { list: "possible_ids", id: "new-value", type: "text", class: "flex-value", onInput: (event) => this.onValueChange(event) }), h("datalist", { id: "possible_ids" }, jsonLdGetByType(this.data, this.attributeType).map((type) => {
          return (h("option", { value: type, key: type }));
        })))), h("button", { onClick: () => this.addAttribute() }, "Save"), h("button", { onClick: () => this.editMode = false }, "Cancel"))));
    }
  }
  get el() { return this; }
  static get style() { return incldeViewEditCss; }
}, [1, "inclde-view-edit", {
    "data": [16],
    "selectedIndex": [2, "selected-index"],
    "subElement": [1, "sub-element"],
    "editMode": [32],
    "attributeName": [32],
    "attributeType": [32],
    "attributeValue": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["inclde-view-edit", "inclde-help-spot"];
  components.forEach(tagName => { switch (tagName) {
    case "inclde-view-edit":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, IncldeViewEdit);
      }
      break;
    case "inclde-help-spot":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { IncldeViewEdit as I, defineCustomElement as d };

//# sourceMappingURL=inclde-view-edit2.js.map