import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { e as jsonLdNodeToName } from './utils.js';

const incldeViewLinkCss = ":host{display:block}.view-link{cursor:pointer;font-style:italic}.view-link-external{text-decoration:underline;color:blue}";

const IncldeViewLink = /*@__PURE__*/ proxyCustomElement(class IncldeViewLink extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.elementSelected = createEvent(this, "elementSelected", 7);
    this.data = [];
    this.selector = undefined;
    this.label = 'Unknown';
  }
  componentWillRender() {
    if (this.selector === undefined) {
      return;
    }
    if (this.data[this.selector]['@id'] !== undefined) {
      this.label = jsonLdNodeToName(this.data[this.selector]);
    }
    else {
      this.label = JSON.stringify(this.data[this.selector]);
    }
  }
  elementClicked() {
    this.elementSelected.emit({
      selectIndex: this.selector,
      selectUrl: this.label,
    });
  }
  render() {
    return (h(Host, null, h("span", { class: this.selector === undefined ? 'view-link view-link-external' : 'view-link', onClick: () => this.elementClicked() }, this.label)));
  }
  static get style() { return incldeViewLinkCss; }
}, [1, "inclde-view-link", {
    "data": [16],
    "selector": [2],
    "label": [1025]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["inclde-view-link"];
  components.forEach(tagName => { switch (tagName) {
    case "inclde-view-link":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, IncldeViewLink);
      }
      break;
  } });
}

export { IncldeViewLink as I, defineCustomElement as d };

//# sourceMappingURL=inclde-view-link2.js.map