const defaultConfig = {
  "title": "Linked Metadata Editor",
  "hideAttributesByDefault": false,
  "allowNewAttributes": true,
};
class ConfigHelper {
  constructor() {
    this.config = defaultConfig;
  }
  static getInstance() {
    if (ConfigHelper.instance === undefined) {
      ConfigHelper.instance = new ConfigHelper();
    }
    return ConfigHelper.instance;
  }
  loadConfig(json) {
    this.mergeConfig(json);
  }
  mergeConfig(config) {
    this.config = Object.assign(Object.assign({}, this.config), config);
  }
  getConfig() {
    return this.config;
  }
  get(key) {
    return this.config[key];
  }
  getSettingsForObj(id, type, attribute) {
    // Default values
    let result = { "visible": !this.get("hideAttributesByDefault"), "editable": true };
    // Match by type
    if (!Array.isArray(type)) {
      type = [type];
    }
    for (let index in this.config["attributConfig"]) {
      let setting = this.config["attributConfig"][index];
      if (setting["onType"] !== undefined && (setting["onType"] === '*' || type.includes(setting["onType"]))) {
        for (let attributeIndex in setting["attributes"]) {
          let attributeSettings = setting["attributes"][attributeIndex];
          if (attributeSettings["name"] === attribute) {
            result["visible"] = !attributeSettings["hidden"];
            result["editable"] = !attributeSettings["readOnly"];
          }
        }
      }
    }
    // Potentially overwrite with match by ID
    for (let index in this.config["attributConfig"]) {
      let setting = this.config["attributConfig"][index];
      if (setting["onId"] === id) {
        for (let attributeIndex in setting["attributes"]) {
          let attributeSettings = setting["attributes"][attributeIndex];
          if (attributeSettings["name"] === attribute) {
            result["visible"] = !attributeSettings["hidden"];
            result["editable"] = !attributeSettings["readOnly"];
          }
        }
      }
    }
    return result;
  }
}

export { ConfigHelper as C };

//# sourceMappingURL=config-helper-d0e78217.js.map