import { r as registerInstance, c as createEvent, h, H as Host } from './index-30b93e82.js';
import { S as SchemaDotOrg } from './schema-dot-org-9cf24ee8.js';
import { i as isNullish, j as jsonLdGetByType, a as jsonLdGetByID, b as jsonLdNodeToTypeIds, c as jsonLdGetSubNodes, d as jsonLdNodeToName, e as jsonLdNodeToType } from './utils-ebc89a03.js';

const incldeAddNodeDialogueCss = ":host{display:block}.container{margin:1em;padding-top:1em;border-top:1px solid #aaa}.flex-container{display:flex}.flex-value{flex-grow:1}button{display:flex}inclde-help-spot{margin-right:0.3em}.flex-container+.flex-container{margin-top:0.2em}button+button{margin-left:0.5em}label+input{margin-left:0.5em}";

const IncldeAddNodeDialogue = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.nodeAdded = createEvent(this, "nodeAdded", 7);
    this.schemaDotOrgDefinition = SchemaDotOrg.getInstance();
    this.typeSpecificContent = [
      {
        "name": "boolean",
        "helpText": "Choose a boolean value (true or false) for the new attribute.",
        "inputElementType": "checkbox",
      },
      {
        "name": "number",
        "helpText": "Choose a number for the new attribute.",
        "inputElementType": "number",
      },
      {
        "name": "string",
        "helpText": "Choose a string value for the new attribute.",
        "inputElementType": "text",
      },
      {
        "name": "array"
      },
    ];
    this.data = undefined;
    this.relationTo = undefined;
    this.allowPrimitives = false;
    this.isOpen = false;
    this.attributeRelation = '';
    this.attributeType = '';
    this.attributeValue = undefined;
  }
  componentWillLoad() {
    this.schemaDotOrgDefinition.awaitSchemaDefinition();
  }
  /**
   * Sets a relation to the given ID for the relationTo node.
   * @param id The ID of the node to point at.
   */
  setRelation(id) {
    if (isNullish(id) || isNullish(this.relationTo)) {
      return;
    }
    let relatedToIndex = jsonLdGetByID(this.data, this.relationTo);
    if (relatedToIndex === undefined) {
      return [];
    }
    let relatedToNode = this.data[relatedToIndex];
    console.log("found relatedToNode", relatedToNode);
    if (relatedToNode[this.attributeRelation] === undefined) {
      relatedToNode[this.attributeRelation] = id;
    }
    else if (Array.isArray(relatedToNode[this.attributeRelation])) {
      let array = relatedToNode[this.attributeRelation];
      array.push(id);
      relatedToNode[this.attributeRelation] = array;
    }
    else {
      relatedToNode[this.attributeRelation] = [relatedToNode[this.attributeRelation], id];
    }
  }
  addAttribute() {
    var _a, _b, _c;
    if (this.attributeType === '') {
      console.error("Attribute name or type is empty");
      return;
    }
    let newValue;
    let newObj;
    if (this.attributeType === 'string') {
      newValue = (_a = this.attributeValue) !== null && _a !== void 0 ? _a : '';
    }
    else if (this.attributeType === 'number') {
      newValue = (_b = this.attributeValue) !== null && _b !== void 0 ? _b : 0;
    }
    else if (this.attributeType === 'boolean') {
      newValue = (_c = this.attributeValue) !== null && _c !== void 0 ? _c : false;
    }
    else if (this.attributeType === 'array') {
      newValue = [];
    }
    else {
      // Check if selected ID exists
      let pos = jsonLdGetByID(this.data, this.attributeValue);
      if (pos === undefined) {
        newValue = { "@id": this.attributeValue };
        newObj = { "@id": this.attributeValue, "@type": this.attributeType };
      }
      else {
        newValue = { "@id": this.attributeValue };
      }
    }
    if (newObj !== undefined) {
      this.data.push(newObj);
    }
    this.setRelation(newValue);
    this.isOpen = false;
    this.attributeValue = undefined;
    this.attributeType = '';
    this.nodeAdded.emit();
  }
  render() {
    return (h(Host, null, this.isOpen ? this.renderOpenState() : this.renderClosedState()));
  }
  renderClosedState() {
    return (h("div", { class: "container" }, h("button", { onClick: () => this.isOpen = true }, h("inclde-help-spot", { helpText: 'Creates a new item. It can be connected with others later.' }), h("span", null, "Create new item"))));
  }
  renderOpenState() {
    // Render three input fields for name, type and value, and a button to add the attribute.
    // But only show the next field each if the previous field is filled out.
    let relationRequired = !isNullish(this.relationTo);
    let hasValueInput = this.attributeValue !== undefined && (typeof this.attributeValue !== 'string' || this.attributeValue.length > 0);
    return (h("div", { class: "container" }, relationRequired && this.renderRelationField(), (this.attributeRelation.length > 0 || !relationRequired) && this.renderTypeField(), (this.attributeType.length > 0) && this.renderValueField(), h("div", { class: "flex-container" }, h("button", { onClick: () => this.addAttribute(), disabled: !(this.attributeType.length > 0 && hasValueInput) }, "Create"), h("button", { onClick: () => this.isOpen = false }, "Cancel"))));
  }
  renderValueField() {
    let isPrimitiveType = this.typeSpecificContent.map((content) => content.name).includes(this.attributeType);
    let renderIdInput = h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value", class: "flex-container" }, h("inclde-help-spot", { helpText: 'Choose a new ID for a new attribute, or an existing ID to connect an existing one.' }), "ID:"), h("input", { list: "possible_ids", id: "new-value", type: "text", class: "flex-value", onInput: (event) => this.onValueChange(event), required: true }), h("datalist", { id: "possible_ids" }, jsonLdGetByType(this.data, this.attributeType).map((type) => {
      return (h("option", { value: type, key: type }));
    })));
    if (isPrimitiveType) {
      return this.renderPrimitiveInput();
    }
    else {
      return renderIdInput;
    }
  }
  renderPrimitiveInput() {
    var _a, _b, _c;
    let isPrimitiveType = this.typeSpecificContent.map((content) => content.name).includes(this.attributeType);
    let hasInputElementType = ((_a = this.typeSpecificContent.find((content) => content.name === this.attributeType)) === null || _a === void 0 ? void 0 : _a.inputElementType) !== undefined;
    if (!isPrimitiveType || !hasInputElementType) {
      return;
    }
    return h("div", { class: "flex-container" }, h("label", { htmlFor: "new-value", class: "flex-container" }, h("inclde-help-spot", { helpText: (_b = this.typeSpecificContent.find((content) => content.name === this.attributeType)) === null || _b === void 0 ? void 0 : _b.helpText }), "Value:"), h("input", { id: "new-value", type: (_c = this.typeSpecificContent.find((content) => content.name === this.attributeType)) === null || _c === void 0 ? void 0 : _c.inputElementType, class: "flex-value", onInput: (event) => this.onValueChange(event), required: true }));
  }
  renderRelationField() {
    return (h("div", { class: "flex-container" }, h("label", { htmlFor: "new-relation", title: 'The relation of the new attribute from the view of the selected object.', class: "flex-container" }, h("inclde-help-spot", { helpText: 'The relation of the new attribute from the view of the selected object.' }), "Relation:"), h("input", { id: "new-relation", type: "text", class: "flex-value", list: "possible_attributes", value: this.attributeRelation, onInput: (event) => this.onAttributeNameChange(event) }), h("datalist", { id: "possible_attributes" }, this.getRelationList().map((property) => {
      return (h("option", { value: property, label: property.replace("https://schema.org/", "") + " - " + property, key: property }));
    }))));
  }
  renderTypeField() {
    var _a;
    let relationIsNullish = this.attributeRelation === null || this.attributeRelation === undefined || this.attributeRelation === '';
    return (h("div", { class: "flex-container" }, h("label", { htmlFor: "new-type", class: "flex-container" }, h("inclde-help-spot", { helpText: 'Choose which type of information to add as an attribute.' }), "Type:"), h("input", { list: "possible_types", id: "new-type", type: "text", class: "flex-value", value: this.attributeType, onInput: (event) => this.onTypeChange(event), required: true }), h("datalist", { id: "possible_types" }, this.allowPrimitives && h("option", { value: "boolean", label: "Native Boolean type" }), this.allowPrimitives && h("option", { value: "number", label: "Native Number type" }), this.allowPrimitives && h("option", { value: "string", label: "Native String type" }), this.allowPrimitives && h("option", { value: "array", label: "Native Array type" }), !relationIsNullish && ((_a = this.schemaDotOrgDefinition.getDataTypesByProperty(this.attributeRelation)) !== null && _a !== void 0 ? _a : []).map((type) => {
      return (h("option", { value: type, label: type.replace("https://schema.org/", "") + " - " + type, key: type }));
    }), relationIsNullish && (this.schemaDotOrgDefinition.getAllClasses()).map((type) => {
      return (h("option", { value: type, label: type.replace("https://schema.org/", "") + " - " + type, key: type }));
    }))));
  }
  onValueChange(event) {
    if (event.target instanceof HTMLInputElement) {
      if (this.attributeType === 'string') {
        this.attributeValue = event.target.value;
      }
      else if (this.attributeType === 'number') {
        this.attributeValue = Number(event.target.value);
      }
      else if (this.attributeType === 'boolean') {
        this.attributeValue = event.target.checked;
      }
      else {
        this.attributeValue = event.target.value;
      }
    }
  }
  onTypeChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeType = event.target.value;
      this.attributeValue = undefined;
    }
  }
  onAttributeNameChange(event) {
    if (event.target instanceof HTMLInputElement) {
      this.attributeRelation = event.target.value;
      this.attributeType = '';
      this.attributeValue = undefined;
    }
  }
  getRelationList() {
    if (isNullish(this.relationTo)) {
      return [];
    }
    else {
      let propertiesList;
      let relatedToIndex = jsonLdGetByID(this.data, this.relationTo);
      if (relatedToIndex === undefined) {
        return [];
      }
      let relatedToNode = this.data[relatedToIndex];
      let typeIDs = jsonLdNodeToTypeIds(relatedToNode);
      //let typeNames: string[] = typeIDs
      //  .map((id) => jsonLdGetByID(this.data, id))
      //  .filter((index) => index !== undefined)
      //  .map((index) => this.data[index!])
      //  .filter((node) => node !== undefined)
      //  .map((node) => jsonLdNodeToName(node));
      let type = typeIDs;
      if (Array.isArray(type)) {
        let tempList = [];
        type.forEach((id) => {
          var _a;
          if (typeof id === 'string') {
            tempList = tempList.concat((_a = this.schemaDotOrgDefinition.getPropertiesByType(id)) !== null && _a !== void 0 ? _a : []);
          }
        });
        tempList = [...new Set(tempList)];
        propertiesList = tempList;
      }
      else if (typeof type === 'string') {
        propertiesList = this.schemaDotOrgDefinition.getPropertiesByType(type);
      }
      propertiesList = propertiesList !== null && propertiesList !== void 0 ? propertiesList : [];
      // Remove already existing properties
      propertiesList = propertiesList.filter((property) => {
        return !Object.keys(this.relationTo).includes(property) &&
          !Object.keys(this.relationTo).includes(property.replace('https://', 'http://'));
      });
      return propertiesList;
    }
  }
};
IncldeAddNodeDialogue.style = incldeAddNodeDialogueCss;

const incldeSidebarElementCss = ":host{display:block;padding:0px}.hidden{display:none}.sidebar-label{font-size:1em;margin:2px;padding:2px}.sidebar-type{font-size:0.75em;line-height:1em;color:#212121;border:1px solid #898989;border-radius:5px;margin:2px;padding:2px;display:inline-block}.sidebar-item{padding-right:1em}.sidebar-item-child{padding-left:20px}.selected{background-color:#ccc !important}.sidebar-item-header{cursor:pointer;padding-bottom:2px;padding-top:2px;display:flex}.button-column{flex:0}.span-column{display:flex;flex:1;flex-direction:column}.sidebar-item-header:hover{background-color:#dbdbdb}.sidebar-propertyname{font-size:0.9em;font-style:italic}.sidebar-properties{padding-left:10px}.sidebar-expand-button{vertical-align:bottom;background:none;border:none;padding:0px;margin:0px;width:25px;height:25px;cursor:pointer}.sidebar-expand-button svg{width:20px;height:20px;fill:#777}.sidebar-expand-button:hover svg{fill:#000}.sidebar-expand-button:active svg{fill:#555}";

const IncldeSidebarElement = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.elementSelected = createEvent(this, "elementSelected", 7);
    this.data = undefined;
    this.selector = undefined;
    this.globalSelector = undefined;
    this.expanded = false;
    this.selected = false;
    this.selctedElement = {};
  }
  updateSelectedElement() {
    if (this.selector == undefined) {
      this.selctedElement = {};
      this.selected = false;
      return;
    }
    this.selctedElement = this.data[this.selector];
    this.selected = this.selector == this.globalSelector;
  }
  componentWillLoad() {
    this.updateSelectedElement();
  }
  toggleExpanded(e) {
    this.expanded = !this.expanded;
    e.stopPropagation();
  }
  elementClicked() {
    this.elementSelected.emit({
      selectIndex: this.selector,
    });
  }
  render() {
    const subNodes = jsonLdGetSubNodes(this.data, this.selctedElement);
    return (h(Host, null, h("div", { class: 'sidebar-item' }, h("div", { onClick: () => this.elementClicked(), class: this.selected ? 'sidebar-item-header selected' : 'sidebar-item-header' }, subNodes.size > 0 && h("div", { class: "column button-column" }, h("button", { type: "button", class: "sidebar-expand-button", onClick: (e) => this.toggleExpanded(e) }, this.expanded ? this.renderChildrenIndicatorOpen() : this.renderChildrenIndicatorClosed())), h("div", { class: "column header-column" }, h("span", { class: "sidebar-label" }, jsonLdNodeToName(this.selctedElement)), jsonLdNodeToType(this.selctedElement).map((y) => h("span", { class: "sidebar-type", key: y }, y)))), subNodes.size > 0 && h("div", { class: "sidebar-item-children" }, h("div", { class: this.expanded ? 'sidebar-item-child' : 'sidebar-item-child hidden' }, this.expanded && Array.from(subNodes).map(([path, id]) => {
      return (h("div", null, h("span", { class: "sidebar-propertyname" }, path.split("/").pop(), ":"), h("div", { class: "sidebar-properties" }, id.map((id) => h("inclde-sidebar-element", { data: this.data, selector: jsonLdGetByID(this.data, id), globalSelector: this.globalSelector })))));
    }))))));
  }
  renderChildrenIndicatorOpen() {
    // Font Awesome SVG icon from https://fontawesome.com/icons/caret-down?f=classic&s=solid
    return h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "1em", viewBox: "0 0 320 512" }, "<!--! Font Awesome Free 6.4.2 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. -->", h("path", { d: "M137.4 374.6c12.5 12.5 32.8 12.5 45.3 0l128-128c9.2-9.2 11.9-22.9 6.9-34.9s-16.6-19.8-29.6-19.8L32 192c-12.9 0-24.6 7.8-29.6 19.8s-2.2 25.7 6.9 34.9l128 128z" }));
  }
  renderChildrenIndicatorClosed() {
    // Font Awesome SVG icon from https://fontawesome.com/icons/caret-right?f=classic&s=solid
    return h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "1em", viewBox: "0 0 256 512" }, "<!--! Font Awesome Free 6.4.2 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. -->", h("path", { d: "M246.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-128-128c-9.2-9.2-22.9-11.9-34.9-6.9s-19.8 16.6-19.8 29.6l0 256c0 12.9 7.8 24.6 19.8 29.6s25.7 2.2 34.9-6.9l128-128z" }));
  }
  static get watchers() { return {
    "selector": ["updateSelectedElement"],
    "data": ["updateSelectedElement"],
    "globalSelector": ["updateSelectedElement"]
  }; }
};
IncldeSidebarElement.style = incldeSidebarElementCss;

export { IncldeAddNodeDialogue as inclde_add_node_dialogue, IncldeSidebarElement as inclde_sidebar_element };

//# sourceMappingURL=inclde-add-node-dialogue_2.entry.js.map