import { r as registerInstance, h, H as Host, c as createEvent } from './index-30b93e82.js';
import { C as ConfigHelper } from './config-helper-d0e78217.js';
import { p as pathTraversalSet } from './utils-ebc89a03.js';

const incldeSidebarCss = ":host{display:block}.subel{padding-left:15px;border:1px solid #999999}";

const IncldeSidebar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.data = undefined;
    this.selectedIndex = undefined;
    this.rerenderTrigger = false;
  }
  getHTML(data) {
    return (h("div", null, data.map((x, i) => [x, i])
      .filter(([x, _i]) => x['@type'] !== undefined && !x['@id'].startsWith('_:'))
      .map(([_x, i]) => h("inclde-sidebar-element", { data: this.data, selector: i, globalSelector: this.selectedIndex })), h("inclde-add-node-dialogue", { data: this.data })));
  }
  nodeAddedHandler(_event) {
    // trick to trigger re-render
    this.rerenderTrigger = !this.rerenderTrigger;
  }
  render() {
    return (h(Host, null, this.getHTML(this.data)));
  }
};
IncldeSidebar.style = incldeSidebarCss;

const incldeViewCss = ":host{display:block;padding-top:5px}.array-entry{margin:5px 5px 5px 15px;border:1px solid #ccc;border-radius:5px;padding-left:5px;padding-bottom:5px}.array-element{margin:5px;padding-bottom:5px;border-bottom:dotted 1px #ccc;gap:1em}.property-container{display:flex;justify-content:space-between;align-items:center}.property-name{padding-right:1em}.property-value{flex-grow:1}inclde-input{display:inline-block}.interface-buttons{float:right}.interface-buttons.offset{margin-right:10px}.interface-buttons button{vertical-align:text-bottom;background:none;border:none;padding:0px;margin:0px;width:20px;height:20px;cursor:pointer}.interface-buttons button:disabled{cursor:default}.interface-buttons button svg{width:20px;height:20px;fill:#777;vertical-align:top}.interface-buttons button:hover svg{fill:#000}.interface-buttons button.danger-btn:hover svg{fill:rgb(210, 48, 48)}.interface-buttons button:active svg{fill:#555}.editing-container{border-top:1px solid #aaa;margin-top:1em;padding-top:1em;margin-bottom:1em}";

const IncldeView = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.redraw = createEvent(this, "redraw", 7);
    this.config = ConfigHelper.getInstance();
    this.data = undefined;
    this.selectedIndex = undefined;
  }
  deleteElement(selector) {
    pathTraversalSet(this.data, selector, undefined);
    this.redraw.emit();
  }
  renderHTML() {
    if (this.selectedIndex === undefined) {
      return;
    }
    else {
      let id = this.data[this.selectedIndex]["@id"] || "";
      let type = this.data[this.selectedIndex]["@type"] || [];
      return (h("div", null, Object.entries(this.data[this.selectedIndex]).map(([key, value]) => {
        const keySettings = this.config.getSettingsForObj(id, type, key);
        if (Array.isArray(value) && keySettings["visible"] === true) {
          return (h("div", { key: key }, h("span", { class: "array-name" }, key.replace("http://schema.org/", ""), ":"), this.renderPredicateActionButtons(key), h("div", { class: "array-entry" }, value.map((_x, index) => (h("div", { class: "array-element property-container" }, h("inclde-input", { class: "property-value", data: this.data, selector: [this.selectedIndex, key, index], isEditable: keySettings["editable"] }), this.renderPropertyActionButtons(index, key)))), h("inclde-view-edit", { data: this.data, selectedIndex: this.selectedIndex, subElement: key }))));
        }
        else if (keySettings["visible"] === true) {
          return (h("div", { class: "property-container", key: key }, h("span", { class: "property-name" }, key + ":"), h("inclde-input", { class: "property-value", data: this.data, selector: [this.selectedIndex, key], isEditable: keySettings["editable"] }), keySettings["editable"] && this.renderPredicateActionButtons(key)));
        }
      }), this.config.get("allowNewAttributes") && this.renderAddAttributeButton(this.selectedIndex)));
    }
  }
  /**
   * Renders html to enable the user to add further attributes to the selected object.
   *
   * @param selectedIndex the index of the selected object of this view.
   * @returns the html
   */
  renderAddAttributeButton(selectedIndex) {
    return h("div", { class: "editing-container" }, h("inclde-view-edit", { data: this.data, selectedIndex: selectedIndex }));
  }
  /**
   * Returns a delete button for elements which do not have any other possible action.
   *
   * @param key the key to delete
   * @returns the html
   */
  renderPredicateActionButtons(key) {
    return h("div", { class: "interface-buttons offset" }, h("button", { class: "danger-btn", onClick: () => this.deleteElement([this.selectedIndex, key]) }, this.renderDeleteIcon()));
  }
  /**
   * Adds buttons for moving up and down or deleting an object.
   *
   * @param index current index of the object
   * @param key the key/name of the object
   * @param value the object
   * @returns the html to render
   */
  renderPropertyActionButtons(index, key) {
    return h("div", { class: "interface-buttons" }, h("button", { class: "danger-btn", onClick: () => this.deleteElement([this.selectedIndex, key, index]) }, this.renderDeleteIcon()));
  }
  renderDeleteIcon() {
    return h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 384 512" }, h("path", { d: "M342.6 150.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L192 210.7 86.6 105.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L146.7 256 41.4 361.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L192 301.3 297.4 406.6c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L237.3 256 342.6 150.6z" }));
  }
  render() {
    return (h(Host, null, this.renderHTML()));
  }
};
IncldeView.style = incldeViewCss;

export { IncldeSidebar as inclde_sidebar, IncldeView as inclde_view };

//# sourceMappingURL=inclde-sidebar_2.entry.js.map