import { EventEmitter } from '../../stencil-public-runtime';
import { NodeObject } from 'jsonld';
import { JsonLdId } from '../../utils/types';
/**
 * This class represents the dialogue that is shown when the user wants to add a new node.
 *
 * It aims to replace the functionality of the inclde-view-edit component in the long term.
 * The functionality of the inclde-view-edit component is currently:
 *
 * - (ATTRIBUTE) Add a new attribute (main purpose)
 * - (RELATION) relate it to the selected node
 * - (NODE) Add a new node to the data, if a unused ID is entered (but only with a relation to an existing node)
 * - (ARRAY_ELEMENT) Add a element to an array attribute of the selected node, if subElement property is set
 *
 * The functionality of the inclde-add-node-dialogue component is currently:
 *
 * - (NODE) Add a new node to the data (main purpose)
 * - (RELATION) Add a relation to an existing node, if such a node is given to the component (only supports https://schema.org/ relations)
*/
export declare class IncldeAddNodeDialogue {
  /**
   * Event that is fired when the new node is added.
   */
  nodeAdded: EventEmitter<CustomEvent>;
  /**
   * The data to which the new node should be added.
   */
  data: NodeObject[];
  /**
   * The node to which the new node should be connected to, if desired.
   * Setting this property will add a relation field to the dialogue.
   */
  relationTo?: JsonLdId;
  /**
   * Setting to determine if it is allowed to add primitives to the data.
   */
  allowPrimitives: boolean;
  /**
   * States whether the dialogue is open or not.
   */
  isOpen: boolean;
  attributeRelation: string;
  attributeType: string;
  attributeValue: string | number | boolean | undefined;
  private schemaDotOrgDefinition;
  private typeSpecificContent;
  componentWillLoad(): void;
  /**
   * Sets a relation to the given ID for the relationTo node.
   * @param id The ID of the node to point at.
   */
  private setRelation;
  private addAttribute;
  render(): any;
  private renderClosedState;
  private renderOpenState;
  private renderValueField;
  private renderPrimitiveInput;
  private renderRelationField;
  private renderTypeField;
  private onValueChange;
  private onTypeChange;
  private onAttributeNameChange;
  private getRelationList;
}
