import * as jsonld from 'jsonld';
import { JsonLdId } from './types';
export declare function jsonLdNodeToName(node: jsonld.NodeObject): string;
/**
 * Returns all IDs of the given object.
 * @param node - The JSON-LD node object to extract the ids from.
 * @returns An array of IDs of the given object.
 */
export declare function jsonLdGetIDsfromNode(node: jsonld.NodeObject | undefined): JsonLdId[] | undefined;
/**
 * Extracts the types (their IDs) from a JSON-LD node object.
 * @param node The JSON-LD node object to extract type IDs from.
 * @returns An array of type IDs for the given node object.
 */
export declare function jsonLdNodeToTypeIds(node: jsonld.NodeObject): JsonLdId[];
/**
 * Extracts the types suffixes/names from the given JSON-LD node object.
 * **It does not return the full types but their suffixes/names.**
 * @param node - The JSON-LD node object to extract types from.
 * @returns An array of strings representing the extracted types.
 * @deprecated Use jsonLdNodeToTypeIds and jsonLDNodeToName instead, as it is bad practice to extract the name from the ID.
 */
export declare function jsonLdNodeToType(node: jsonld.NodeObject): string[];
/**
 * Returns the index of the first element in the given array of JSON-LD node objects that has the specified ID.
 * @param obj The array of JSON-LD node objects to search.
 * @param id The ID to search for.
 * @returns The index of the first element with the specified ID, or undefined if no such element is found.
 */
export declare function jsonLdGetByID(obj: Array<jsonld.NodeObject>, id: string): number | undefined;
export declare function jsonLdGetByType(obj: Array<jsonld.NodeObject>, type: string): Array<string>;
export declare function jsonLdIsLocalID(obj: Array<jsonld.NodeObject>, id: string): boolean;
export declare function jsonLdGetSubNodes(data: Array<jsonld.NodeObject>, obj: jsonld.NodeObject, path?: string): Map<string, string[]>;
export declare function pathTraversal(obj: any, path: (string | number)[]): any;
export declare function pathTraversalSet(obj: any, path: (string | number)[], value: any): void;
/**
 * Type guard that checks if the given object is null, undefined or an empty string.
 * @param obj - The object to check.
 * @returns A boolean indicating whether the object is nullish or not.
 */
export declare function isNullish(obj: any): obj is null | undefined | "";
